==> component-layout-1.0.7.tgz: package/icode.config.js <==
const path = require('path');
const projectRoot = process.cwd();

// const build = require('./build');

module.exports = {
  layoutRoot: path.join(__dirname, 'src'),
  templatePath: path.join(__dirname, 'src/index.ejs'),
  publicPath: '/', // 子应用base路径， 默认为包名
  outputPath: path.join(projectRoot, './dist'), // 打包文件输出地址；配置值时，基于项目根目录，默认为：'./libDist'
  isBundleAnalyzerPlugin: false,
  packEntry: {
    button: './src/index',
  },
  // lessVariables: {
  //   'primary-color': '#ff0000',
  //   'primaryColor': '#ff0000',
  //   '@primary-color': '#000'
  // },
  webpackConfig: (config, options) => {
    config.resolve.alias = {
      '@icode-run/component-layout': path.join(__dirname),
      'Component': path.join(projectRoot)
    };

    config.devServer.proxy = {
      '/web': {
        //target: 'http://test.icoderun.com:2225/',
        target: 'http://www.icoderun.com/',
        changeOrigin: true,
      },
      '/lowcodeApi': {
        //target: 'http://test.icoderun.com:2225/',
        target: 'http://www.icoderun.com/',
        changeOrigin: true,
      },
      '/staticImages': {
        //target: 'http://test.icoderun.com:2225/',
        target: 'http://www.icoderun.com/',
        changeOrigin: true,
      }
    };

    config.plugins.push(
      new options.moduleFederationPlugin({
        name: 'icodeRun',
        filename: 'remoteEntry.js',
        library: { type: 'var', name: 'icodeRun' },
        exposes: {
          './DatePicker': '/Volumes/projects/low-code-dev/icode-component/packages/date-picker/src',
        },
        shared: {
          react: { singleton: true },
          'react-dom': { singleton: true },
        },
      }),
      new options.monacoWebpackPlugin({
        languages: ['javascript', 'css', 'json']
      })
    );

    return config;
  },
};

==> component-layout-1.0.8.tgz: package/icode.config.js <==
const path = require('path');
const projectRoot = process.cwd();

// const build = require('./build');

module.exports = {
  layoutRoot: path.join(__dirname, 'src'),
  templatePath: path.join(__dirname, 'src/index.ejs'),
  publicPath: '/', // 子应用base路径， 默认为包名
  outputPath: path.join(projectRoot, './dist'), // 打包文件输出地址；配置值时，基于项目根目录，默认为：'./libDist'
  isBundleAnalyzerPlugin: false,
  packEntry: {
    button: './src/index',
  },
  // lessVariables: {
  //   'primary-color': '#ff0000',
  //   'primaryColor': '#ff0000',
  //   '@primary-color': '#000'
  // },
  webpackConfig: (config, options) => {
    config.resolve.alias = {
      '@icode-run/component-layout': path.join(__dirname),
      'Component': path.join(projectRoot),


      '@icode-run/utils': path.resolve(__dirname, '../utils'),
      '@icode-run/enum-input': path.resolve(__dirname, '../enum-input'),
      '@icode-run/select': path.resolve(__dirname, '../select'),
      '@icode-run/postman': path.resolve(__dirname, '../postman'),
      'data-source': path.resolve(__dirname, '../../../data-source'),
      'menuDrop': path.resolve(__dirname, '../../../my-designer/src/components/MenuDrop'),
      'my-designer': path.resolve(__dirname, '../../../my-designer'),

      '@/utils/request': path.join(__dirname, '../../../my-web/src/utils/request.js'),
      '@/language': path.join(__dirname, '../../../my-designer/src/language'),
      'dom-container': path.join(__dirname, '../../../dom-container'),
      'api-doc': path.join(__dirname, '../../../my-web/src/pages/apiDoc'),
    };

    config.devServer.proxy = {
      '/icodeRun': {
        //target: 'http://test.icoderun.com:2225/',
        //target: 'http://www.icoderun.com/',
        target: 'https://icode-run.github.io/',
        changeOrigin: true,
      },
      '/lowcodeApi': {
        //target: 'http://test.icoderun.com:2225/',
        target: 'http://www.icoderun.com/',
        changeOrigin: true,
      },
      '/staticImages': {
        //target: 'http://test.icoderun.com:2225/',
        target: 'http://www.icoderun.com/',
        changeOrigin: true,
      }
    };

    config.plugins.push(
      new options.moduleFederationPlugin({
        name: 'icodeRun',
        filename: 'remoteEntry.js',
        library: { type: 'var', name: 'icodeRun' },
        exposes: {
          './DatePicker': '/Volumes/projects/low-code-dev/icode-component/packages/date-picker/src',
        },
        shared: {
          react: { singleton: true },
          'react-dom': { singleton: true },
        },
      }),
      new options.monacoWebpackPlugin({
        languages: ['javascript', 'css', 'json']
      })
    );

    return config;
  },
};
